native_crash library
Classes
- NativeCrash
- Dart interface for interacting with the native_crash plugin.
Functions
-
crashOnDevMode(
FutureOr< void> builder(), {FutureOr<void> onDevModeDetected()?}) → Future<void> - This will kill your app when the device is in dev mode.
-
crashOnEmulator(
FutureOr< void> builder(), {FutureOr<void> onEmulatorDetected()?}) → Future<void> - This will kill your app when the device is an emulator.
-
crashOnJailBreak(
FutureOr< void> builder(), {FutureOr<void> onRootJailBreakDetected()?}) → Future<void> - This will kill your app when the device is jail broken or rooted.