NativeCrash class

Dart interface for interacting with the native_crash plugin.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkDevMode() Future<bool>
checkDevMode
checkEmulator() Future<bool>
checkEmulator
checkJailBreak({bool enableLogging = false}) Future<bool>
checkJailBreak
crash([String? message]) Future<void>
crash