NativeCrashPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NativeCrashPlatform
Implementers

Constructors

NativeCrashPlatform()
Constructs a NativeCrashPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDevMode() → Future<bool>
checkEmulator() → Future<bool>
checkJailBreak({bool enableLogging = false}) → Future<bool>
crash([String? message]) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ NativeCrashPlatform
The default instance of NativeCrashPlatform to use.
getter/setter pair